#procedure DoSum(ucounter,dcounter)
****************************************************************************
**
**  Filename:
**            DoSum.prc
**
**  Authors: 
**            Sven O. Moch and Peter Uwer
**
**  Purpose: 
**            User front-end to the \XSummer\ package. The first parameter
**            denotes the index of the innermost summation, the 
**            second is the index of the outermost sum, which should be summed.
**            For example
**            \begin{verbatim}
**                #call DoSum(3,1)
**            \end{verbatim}
**            would do the sums over $j_3$, $j_2$, $j_1$ in this order.
**
**  Comments:
**
**
**  Revision: 
**            $Id: DoSum.prc,v 1.0 2005/08/02 10:09:54 puwer Exp $
**
**            $Log: DoSum.prc,v $
**            Revision 1.0  2005/08/02 10:09:54  puwer
**            Initial revision
**
**
****************************************************************************
*
* start summation
*
#do counter = `ucounter',`dcounter',-1

#call Makej(`counter')

#do icounter = `ucounter',1,-1
#call DoTheta(`icounter')
.sort(PolyFun=acc):DoTheta`icounter';
#enddo
#call DoTheta(0)
.sort(PolyFun=acc):DoTheta0;

#do icounter = `counter',`counter'
SplitArg,((j`icounter')),den;
id den(j`icounter') 	   = den`icounter'(0,j`icounter');
id den(x1?,j`icounter')  = den`icounter'(x1,j`icounter');
id den(x1?,-j`icounter') = den`icounter'(x1,-j`icounter');
#enddo

#call DoSynch(`counter')

#do icounter = `counter'-1,1,-1
#call SplitDen(`icounter')
#enddo
.sort:SplitDen-`counter';
#do icounter = `counter'-1,1,-1
#call DoTheta(`icounter')
#enddo
#call DoTheta(0)

.sort:CleanUpTheta;

*
*   final regularization of the sum
*   introduction of dangerous binomials.
*
*   adjust infinite sums here
*
#if `counter' == 1
SplitArg,((inf)),sum`counter';
id sum`counter'(j`counter',x1?pos0_,x2?int_,inf) = sum`counter'(j`counter',x1,inf);
#endif

#call RegSum(`counter')
.sort:RegSum`counter';

repeat id  pow(x1?,n0?int_)*pow(x2?,n0?int_) =  pow(x1*x2,n0);
repeat id  pow(x1?,n0?int_)*pow(x1?,n1?int_) = pow(x1,n0+n1);
id  pow(x1?,0) = 1;
id  pow(1,x1?) = 1;


#if `counter' == 1
*
* evacuate powers of x1,...,S1(...,inf),... before doing the last sum
*
	id acc(x?) = x;
	B sum`counter' j`counter' den`counter' pow`counter' fac`counter' invfac`counter' S`counter' bino`counter';
	.sort: Evacuate`counter';
	Collect acc;
#endif

*
* now really do the sums
* 
#call SumIt(`counter')

#if `counter' == 1
	id acc(x?) = x;
	id ep^n?*acc(x?) = acc(ep^n*x);
	#do counter = 2,`MAXCOUNTER';
	id z`counter'^n?*acc(x?) = acc(z`counter'^n*x);
	#enddo
#endif

#do counter = `counter',1,-1  
id pow`counter'(x1?,x2?,x3?) = pow(x1,x2+x3);
id pow`counter'(x1?,x2?) = pow(x1,x2);
#enddo
id pow(x1?,x2?,x3?) = pow(x1,x2+x3);
id x1?^n0?int_*pow(x1?,n1?int_) = pow(x1,n0+n1);
id pow(x1?,0) = 1;
id pow(1,x1?) = 1;

*
* delete inf^k?pos_*pow(x?,inf)-terms --> assume x < 1
*
SplitArg,((inf)),pow;
id pow(x?,inf) = 0;
id pow(x?,n0?,inf) = 0;

.sort(PolyFun=acc):SumIt`counter';

#call SimplifyFacGam

id num(x?) = x;
repeat id pow(x1?,n1?)*pow(x2?,n1?) = pow(x1*x2,n1);

*
* some simplifactions of arguments of S-Sums, if necessary
*
#call SimplifySumArgs

repeat id x?*den(x?) = 1;
id S(R(?a),X(?x),0) = 0;
#call SubsS(0)

SplitArg,((inf)),S;
id S(R(?a),X(?x),x?,+inf) = S(R(?a),X(?x),+inf);

.sort:EndSum`counter';

#call BasisS(0)

#enddo
*
* end generic summation
*
#endprocedure
*************************************************************************
* Local variables:
* modify-insert-tag: nil
* comment-start: "*"
* tab-width: 2
* End:
*************************************************************************

