#procedure DoTheta(i)
****************************************************************************
**
**  Filename:
**            DoTheta.prc
**
**  Authors: 
**            Sven O. Moch and Peter Uwer
**
**  Purpose: 
**            Simplifies combinations of 
**            \keyword{theta}, \keyword{delta}, \keyword{deltap}
**            and \keyword{sum} functions, defined for each sum over $j_i$. 
**            The argument specifies the index $i$ of the sum to be adjusted 
**            (argument $i=0$ implies no sum).
**
**  Comments:
**            This procedure is a modified version of a similiar procedure 
**            in the Summer package written by J.A.M. Vermaseren.
**
**            Note: j`i' >= 0 and  integer
**  					theta(x)  = 1, x >= 0, = 0, x < 0
**            delta(x)  = 1, x = 0,  = 0, x != 0
**            deltap(x) = 1, x != 0, = 0, x = 0
**
**  Revision: 
**            $Id: DoTheta.prc,v 1.0 2005/08/02 10:09:54 puwer Exp $
**
**            $Log: DoTheta.prc,v $
**            Revision 1.0  2005/08/02 10:09:54  puwer
**            Initial revision
**
**
****************************************************************************
*
repeat id f?{theta,theta0,...,theta`i'}(x1?,x2?,?a) = f(x1+x2,?a);
repeat id f?{delta,delta0,...,delta`i'}(x1?,x2?,?a) = f(x1+x2,?a);
repeat id f?{deltap,deltap0,...,deltap`i'}(x1?,x2?,?a) = f(x1+x2,?a);
id  f?{theta0,...,theta`i'}(x?) = theta(x);
id  f?{delta0,...,delta`i'}(x?) = delta(x);
id  f?{deltap0,...,deltap`i'}(x?) = deltap(x);
id  theta_(x?) = theta(x);
id  delta_(x?) = delta(x);
id  deltap_(x?) = deltap(x);
repeat id theta(x?)*theta(x?) = theta(x);
repeat id delta(x?)*delta(x?) = delta(x);
repeat id deltap(x?)*deltap(x?) = deltap(x);

SplitArg,((j`i')),theta,delta,deltap;
id  delta(j`i') = delta`i'(0,j`i');
id  deltap(j`i') = deltap`i'(0,j`i');
id  theta(j`i') = theta`i'(0,j`i');
#do counter = 1,`MAXCOUNTER'
  id  delta(x?,`counter'*j`i') = delta`i'(x,`counter'*j`i');
  id  deltap(x?,`counter'*j`i') = deltap`i'(x,`counter'*j`i');
  id  theta(x?,`counter'*j`i') = theta`i'(x/`counter',j`i');
  id  delta(x?,-`counter'*j`i') = delta`i'(-x,`counter'*j`i');
  id  deltap(x?,-`counter'*j`i') = deltap`i'(-x,`counter'*j`i');
  id  theta(x?,-`counter'*j`i') = theta`i'(x/`counter',-j`i');

  id  delta`i'(x?pos_,`counter'*j`i') = 0;
  id  deltap`i'(x?pos_,`counter'*j`i') = 1;
#enddo
id  theta`i'(x?pos0_,j`i') = 1;
id  theta`i'(x?neg_,-j`i') = 0;


#if `i' == 0
*
*   no sum
*
#else
*
*   eliminate delta`i' functions 
*
#do counter = 1,`MAXCOUNTER'
 	id  sum`i'(j`i',x1?,x2?)*delta`i'(x?,`counter'*j`i') =
		replace_(j`i',-x/`counter')*theta(x2-j`i')*theta(j`i'-x1)*theta(x2-x1);
#enddo
  if ( count(sum`i',1) == 0 );
    id  theta`i'(x1?,x2?) = theta(x1+x2);
		id  delta`i'(x1?,x2?) = delta(x1+x2);
		id  deltap`i'(x1?,x2?) = deltap(x1+x2);
  else;
#do counter = 1,`MAXCOUNTER'
    repeat id sum`i'(j`i',x1?,x2?)*deltap`i'(x?,`counter'*j`i') = 
			sum`i'(j`i',x1,x2)*(theta`i'((x-1)/`counter',j`i')+theta`i'(-(x+1)/`counter',-j`i'));
#enddo
    repeat id theta`i'(?a)*theta`i'(?a) = theta`i'(?a);
  endif;

#endif
*
*   theta functions
*
repeat id theta`i'(x1?,j`i')*theta`i'(x2?,j`i') =
	+theta`i'(x1,j`i')*theta(x2-x1)
	+theta`i'(x2,j`i')*(theta(x1-x2)-delta(x1-x2))
	;
repeat id theta`i'(x1?,-j`i')*theta`i'(x2?,-j`i') =
	+theta`i'(x1,-j`i')*theta(x2-x1)
	+theta`i'(x2,-j`i')*(theta(x1-x2)-delta(x1-x2))
	;

#if `i' == 0
*
*   no sum
*
#else
id sum`i'(j`i',x1?,x2?)*theta`i'(x?,j`i') =
	+sum`i'(j`i',x1,x2)*theta(x1+x)
  +sum`i'(j`i',-x,x2)*theta(x2+x)*(theta(-x1-x)-delta(x+x1))
	;
id sum`i'(j`i',x1?,x2?)*theta`i'(x?,-j`i') =
  +sum`i'(j`i',x1,x2)*theta(x-x2)
  +sum`i'(j`i',x1,x)*theta(x-x1)*(theta(x2-x)-delta(x-x2))
	;
#endif
*
*
SplitArg,((inf)),theta,delta;
id  theta(inf) = 1;
id  theta(-inf) = 0;
id  theta(n1?,inf) = 1;
id  theta(n1?,-inf) = 0;
id  delta(inf) = 0;
id  delta(x1?number_,inf) = 0;
id  delta(x1?number_,-inf) = 0;
id  delta(x1?,inf) = delta(x1+inf);
id  delta(x1?,-inf) = delta(x1-inf);

*
*   eliminate finite sums recursively
*
if ( match(sum`i'(j`i',x1?,x2?)) );
	id  sum`i'(j`i',x1?,x2?) = sum`i'(j`i',x1,x2,x2-x1);
	if ( match(sum`i'(j`i',x1?,x2?,x3?pos0_)) );
    id  delta`i'(x1?,x2?) = delta_(x1+x2);
    id  deltap`i'(x1?,x2?) = deltap_(x1+x2);
    id  theta`i'(x1?,x2?) = theta_(x1+x2);
    id  den`i'(x1?,x2?) = den(x1+x2);
    id  fac`i'(x1?,x2?) = fac(x1+x2);
    id  invfac`i'(x1?,x2?) = invfac(x1+x2);
    id  S`i'(R(?a),X(?x),x1?,x2?) = S(R(?a),X(?x),x1+x2);
    id  bino`i'(x1?,x2?,x3?) = fac(x1)*invfac(x2+x3)*invfac(x1-x2-x3);
    id  sign`i'(x?) = sign(x);
    repeat id sum`i'(j`i',x1?,x2?,x3?pos0_) =
         sum`i'(j`i',x1,x2-1,x3-1)+replace_(j`i',x2);
    id  sum`i'(j`i',x1?,x2?,x3?neg_) = 0;
    #do ii = `i'+1,`MAXWEIGHT'
    	if ( match(sum`ii'(j`ii',x1?,x2?)) );
        id  sum`ii'(j`ii',x1?,x2?) = sum`ii'(j`ii',x1,x2,x2-x1);
        if ( match(sum`ii'(j`ii',x1?,x2?,x3?int_)) );
  				id  theta`ii'(x1?,x2?) = theta_(x1+x2);
  				id  den`ii'(x1?,x2?) = den(x1+x2);
  				id  fac`ii'(x1?,x2?) = fac(x1+x2);
  				id  invfac`ii'(x1?,x2?) = invfac(x1+x2);
  				id  S`ii'(R(?a),X(?x),x1?,x2?) = S(R(?a),X(?x),x1+x2);
  				id  bino`ii'(x1?,x2?,x3?) = fac(x1)*invfac(x2+x3)*invfac(x1-x2-x3);
  				id  sign`ii'(x?) = sign(x);
  				repeat id sum`ii'(j`ii',x1?,x2?,x3?pos0_) =
     				sum`ii'(j`ii',x1,x2-1,x3-1)+replace_(j`ii',x2);
  				id  sum`ii'(j`ii',x1?,x2?,x3?neg_) = 0;
       	else;
  				id  sum`ii'(j`ii',x1?,x2?,x3?) = sum`ii'(j`ii',x1,x2);
    #enddo
    #do ii = `i'+1,`MAXWEIGHT'
    		endif;
   		endif;
    #enddo
	else;
   		id  sum`i'(j`i',x1?,x2?,x3?neg_) = 0;
   		id  sum`i'(j`i',x1?,x2?,x3?) = sum`i'(j`i',x1,x2);
	endif;
else;
		id  theta`i'(x1?,x2?) = theta_(x1+x2);
		id  delta`i'(x1?,x2?) = delta_(x1+x2);
		id  deltap`i'(x1?,x2?) = deltap_(x1+x2);
		id  den`i'(x1?,x2?) = den(x1+x2);
		id  fac`i'(x1?,x2?) = fac(x1+x2);
		id  invfac`i'(x1?,x2?) = invfac(x1+x2);
		id  S`i'(R(?a),X(?x),x1?,x2?) = S(R(?a),X(?x),x1+x2);
		id  bino`i'(x1?,x2?,x3?) = fac_(x1)*invfac_(x2+x3)*invfac_(x1-x2-x3);
		id  sign`i'(x?) = sign_(x);
endif;


SplitArg,(inf),theta,delta;
id  theta(inf) = 1;
id  theta(-inf) = 0;
id  theta(n1?,inf) = 1;
id  theta(n1?,-inf) = 0;
id  delta(inf) = 0;
id  delta(x1?number_,inf) = 0;
id  delta(x1?number_,-inf) = 0;


id  theta(x1?,x2?) = theta(x1+x2);
id  delta(x1?,x2?) = delta(x1+x2);
id  deltap(x1?,x2?) = deltap(x1+x2);
id  delta(x?) = delta_(x);
id  delta_(x?) = delta(x);
id  deltap(x?) = deltap_(x);
id  deltap_(x?) = deltap(x);
id  theta(x?) = theta_(x);
id  theta_(x?) = theta(x);

#endprocedure
*************************************************************************
* Local variables:
* modify-insert-tag: nil
* comment-start: "*"
* tab-width: 2
* End:
*************************************************************************
